Learn R Programming

cmprskQR (version 0.9.0)

summary.crrQR: Summary method for crrQR

Description

generate and print summaries of crrQR output

Usage

## S3 method for class 'crrQR':
summary(object, conf.int = 0.95, digits =
max(options()$digits - 5, 2), ...)

## S3 method for class 'summary.crrQR':
print(x, digits=max(options()$digits - 4, 3), ...)

Arguments

object
an object of class crrQR (output from the crrQR function)
conf.int
the level for a two-sided confidence interval on the coefficients. Default is 0.95.
digits
in summary.crrQR, digits determines the number of significant digits retained in the p-values. In print.summary.crrQR, digits sets the values of the digits option for printing the
...
included for compatibility with the generic functions. Not currently used.
x
an object of class summary.crrQR (output from the summary method for crrQR)

Value

  • summary.crrQR returns a list of class summary.crrQR, which contains components
  • callthe call to crr
  • nthe number of observations used in fitting the model
  • n.missingthe number of observations removed by crr from the input data due to missing values
  • ave.effvector of average effects of covariates
  • var.ave.effvector of corresponding variances
  • p.signf.testp-values for testing average effect=0
  • cnst.testscores of test on constant effect
  • var.cnst.testvariances of the score
  • p.cnst.testp-values for the test

Details

The summary method calculates the average effects, the variances and p-values of the test on the effect beeing 0. Furthermore it performs a test for constant coefficients. The print method prints a fairly standard format tabular summary of the results.

See Also

crrQR

Examples

Run this code
## see examples in the crrQR help file

Run the code above in your browser using DataLab